@@ -67,6 +67,7 @@ public:
     using TreeItem::appendChild;
     using TreeItem::deleteChildren;
     using TreeItem::isExpanded;
+    using TreeItem::parent;
 
     using TreeItem::model;
 
@@ -156,6 +157,7 @@ public:
 
     Watches *watches() const { return watches_; }
     Locals *locals(const QString &name = "Locals");
+    QHash<QString, Locals*> allLocals() const;
 
     void fetchMoreChildren() {}
 
@@ -175,6 +177,7 @@ public:
     VariablesRoot* root() const { return universe_; }
     Watches* watches() const { return universe_->watches(); }
     Locals* locals(const QString &name = "Locals") const { return universe_->locals(name); }
+    QHash<QString, Locals*> allLocals() const { return universe_->allLocals(); }
 
 public Q_SLOTS:
     void variableWidgetShown();
