@@ -54,6 +54,8 @@
 #include "parsejob.h"
 #include "parserdependencypolicy.h"
 #include <editor/modificationrevisionset.h>
+#include <interfaces/icore.h>
+#include <qcoreapplication.h>
 
 //@todo Enable this again once languageForUrl is thread-safe
 const bool separateThreadForHighPriority = true;
@@ -65,7 +67,7 @@ class BackgroundParserPrivate
 {
 public:
     BackgroundParserPrivate(BackgroundParser *parser, ILanguageController *languageController)
-        :m_parser(parser), m_languageController(languageController), m_mutex(QMutex::Recursive)
+        :m_parser(parser), m_languageController(languageController), m_mutex(QMutex::Recursive), m_shuttingDown(false)
     {
         parser->d = this; //Set this so we can safely call back BackgroundParser from within loadSettings()
 
@@ -109,10 +111,11 @@ public:
     // Non-mutex guarded functions, only call with m_mutex acquired.
     void parseDocumentsInternal()
     {
+        if(m_shuttingDown)
+            return;
         // Create delayed jobs, that is, jobs for documents which have been changed
         // by the user.
         QList<ParseJob*> jobs;
-
         for(QHash<KUrl, DocumentChangeTracker*>::iterator it = m_delayedParseJobs.begin(); it != m_delayedParseJobs.end(); ) {
             KUrl url(it.key());
 
@@ -120,6 +123,7 @@ public:
                 kDebug() << "already parsing" << url << ", delaying the parse-job";
                 ++it; //Add the delayed job later
             }else{
+                kDebug() << "creating job from delayed job";
                 ParseJob* job = createParseJob(url,
                                             TopDUContext::AllDeclarationsContextsAndUses,
                                             QList<QPointer<QObject> >());
@@ -128,7 +132,7 @@ public:
                     jobs.append(job);
                     specialParseJob = job;
                 } else {
-                    kWarning() << "No job created for url " << it.key();
+                    kDebug() << "No job created for url " << it.key();
                 }
                 delete *it;
                 it = m_delayedParseJobs.erase(it);
@@ -181,6 +185,9 @@ public:
         //We don't hide the progress-bar in updateProgressBar, so it doesn't permanently flash when a document is reparsed again and again.
         if(m_doneParseJobs == m_maxParseJobs)
             emit m_parser->hideProgress(m_parser);
+        
+        if(!m_delayedParseJobs.isEmpty())
+            startTimerThreadSafe();
     }
 
     ParseJob* createParseJob(const KUrl& url, TopDUContext::Features features, QList<QPointer<QObject> > notifyWhenReady)
@@ -188,11 +195,11 @@ public:
         QList<ILanguage*> languages = m_languageController->languagesForUrl(url);
         foreach (ILanguage* language, languages) {
             if(!language) {
-                kWarning(9504) << "got zero language for" << url;
+                kWarning() << "got zero language for" << url;
                 continue;
             }
             if(!language->languageSupport()) {
-                kWarning(9504) << "language has no language support assigned:" << language->name();
+                kWarning() << "language has no language support assigned:" << language->name();
                 continue;
             }
             ParseJob* job = language->languageSupport()->createParseJob(url);
@@ -220,9 +227,9 @@ public:
         }
 
         if(languages.isEmpty())
-            kWarning(9504) << "found no languages for url" << url;
+            kDebug() << "found no languages for url" << url;
         else
-            kWarning(9504) << "could not create parse-job for url" << url;
+            kDebug() << "could not create parse-job for url" << url;
 
         //Notify that we failed
         typedef QPointer<QObject> Notify;
@@ -286,6 +293,9 @@ public:
     QTimer m_timer;
     int m_delay;
     int m_threads;
+    
+    bool m_shuttingDown;
+    
     struct DocumentParseTarget {
         QPointer<QObject> notifyWhenReady;
         int priority;
@@ -349,6 +359,12 @@ public:
 BackgroundParser::BackgroundParser(ILanguageController *languageController)
     : QObject(languageController), d(new BackgroundParserPrivate(this, languageController))
 {
+    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(aboutToQuit()));
+}
+
+void BackgroundParser::aboutToQuit()
+{
+    d->m_shuttingDown = true;
 }
 
 BackgroundParser::~BackgroundParser()
@@ -521,7 +537,6 @@ void BackgroundParser::parseComplete(ThreadWeaver::Job* job)
             //has a virtual destructor that may lock the duchain, leading to deadlocks
             delete parseJob;
         }
-
         //Continue creating more parse-jobs
         QMetaObject::invokeMethod(this, "parseDocuments", Qt::QueuedConnection);
     }
@@ -566,8 +581,9 @@ void BackgroundParser::resume()
 void BackgroundParser::updateProgressBar()
 {
     if (d->m_doneParseJobs >= d->m_maxParseJobs) {
-        if(d->m_doneParseJobs > d->m_maxParseJobs)
-            kWarning() << "m_doneParseJobs larger than m_maxParseJobs:" << d->m_doneParseJobs << d->m_maxParseJobs;
+        if(d->m_doneParseJobs > d->m_maxParseJobs) {
+            kDebug() << "m_doneParseJobs larger than m_maxParseJobs:" << d->m_doneParseJobs << d->m_maxParseJobs;
+        }
         d->m_doneParseJobs = 0;
         d->m_maxParseJobs = 0;
     } else {
@@ -666,8 +682,7 @@ void BackgroundParser::rangeContentsChanged(KTextEditor::SmartRange* range, KTex
 }
 
 void BackgroundParser::startTimer() {
-    if (!d->m_timer.isActive())
-        d->m_timer.start(d->m_delay);
+    d->m_timer.start(d->m_delay);
 }
 
 
