@@ -24,9 +24,26 @@
 #include <interfaces/icore.h>
 
 namespace KDevelop {
-
+    
 static bool onDiskChangesForbidden = false;
 
+QString CodeRepresentation::rangeText(KTextEditor::Range range) const
+{
+    Q_ASSERT(range.end().line() < lines());
+    
+    //Easier for single line ranges which should happen most of the time
+    if(range.onSingleLine())
+        return QString( line( range.start().line() ).mid( range.start().column(), range.columnWidth() ) );
+    
+    //Add up al the requested lines
+    QString rangedText = line(range.start().line()).mid(range.start().column());
+    
+    for(int i = range.start().line() + 1; i <= range.end().line(); ++i)
+        rangedText += '\n' + ((i == range.end().line()) ? line(i).left(range.end().column()) : line(i));
+    
+    return rangedText;
+}
+
 class EditorCodeRepresentation : public DynamicCodeRepresentation {
   public:
   EditorCodeRepresentation(KTextEditor::Document* document) : m_document(document) {
@@ -49,6 +66,10 @@ class EditorCodeRepresentation : public DynamicCodeRepresentation {
     return m_document->setText(text);
   }
   
+  bool fileExists(){
+    return QFile(m_document->url().path()).exists();
+  }
+  
   void startEdit() {
       m_document->startEditing();
   }
@@ -84,6 +105,7 @@ class FileCodeRepresentation : public CodeRepresentation {
           data = file.readAll();
           lineData = data.split('\n');
         }
+        m_exists = file.exists();
     }
     
     QString line(int line) const {
@@ -114,9 +136,14 @@ class FileCodeRepresentation : public CodeRepresentation {
       return false;
     }
     
+    bool fileExists(){
+      return m_exists;
+    }
+    
   private:
     //We use QByteArray, because the column-numbers are measured in utf-8
     IndexedString m_document;
+    bool m_exists;
     QList<QByteArray> lineData;
     QByteArray data;
 };
@@ -144,6 +171,7 @@ class ArtificialStringData : public QSharedData {
 class StringCodeRepresentation : public CodeRepresentation {
   public:
     StringCodeRepresentation(KSharedPtr<ArtificialStringData> _data) : data(_data) {
+      Q_ASSERT(data);
     }
     
     QString line(int line) const {
@@ -166,21 +194,45 @@ class StringCodeRepresentation : public CodeRepresentation {
         return true;
     }
     
+    bool fileExists(){
+        return false;
+    }
+    
   private:
     KSharedPtr<ArtificialStringData> data;
 };
 
 static QHash<IndexedString, KSharedPtr<ArtificialStringData> > artificialStrings;
 
-CodeRepresentation* createCodeRepresentation(IndexedString url) {
+//Return the representation for the given URL if it exists, or an empty pointer otherwise
+KSharedPtr<ArtificialStringData> representationForUrl(IndexedString url)
+{
     if(artificialStrings.contains(url))
-        return new StringCodeRepresentation(artificialStrings[url]);
+        return artificialStrings[url];
+    else
+    {
+        IndexedString constructedUrl(CodeRepresentation::artificialUrl(url.str()));
+        if(artificialStrings.contains(constructedUrl))
+            return artificialStrings[constructedUrl];
+        else
+            return KSharedPtr<ArtificialStringData>();
+    }
+}
+
+bool artificialCodeRepresentationExists(IndexedString url)
+{
+    return !representationForUrl(url).isNull();
+}
+
+CodeRepresentation::Ptr createCodeRepresentation(IndexedString url) {
+    if(artificialCodeRepresentationExists(url))
+        return CodeRepresentation::Ptr(new StringCodeRepresentation(representationForUrl(url)));
     
   IDocument* document = ICore::self()->documentController()->documentForUrl(url.toUrl());
   if(document && document->textDocument())
-    return new EditorCodeRepresentation(document->textDocument());
+    return CodeRepresentation::Ptr(new EditorCodeRepresentation(document->textDocument()));
   else
-    return new FileCodeRepresentation(url);
+    return CodeRepresentation::Ptr(new FileCodeRepresentation(url));
 }
 
 void CodeRepresentation::setDiskChangesForbidden(bool changesForbidden)
@@ -188,8 +240,26 @@ void CodeRepresentation::setDiskChangesForbidden(bool changesForbidden)
     onDiskChangesForbidden = changesForbidden;
 }
 
+KUrl CodeRepresentation::artificialUrl(const QString & name)
+{
+    KUrl url(name);
+    url.setScheme("artificial");
+    url.cleanPath();
+    
+    return url;
+}
+
 InsertArtificialCodeRepresentation::InsertArtificialCodeRepresentation(IndexedString file, QString text) : m_file(file) {
-    artificialStrings.insert(file, KSharedPtr<ArtificialStringData>(new ArtificialStringData(text)));
+    Q_ASSERT(!artificialStrings.contains(m_file));
+    if(m_file.toUrl().isRelative())
+        m_file = IndexedString(CodeRepresentation::artificialUrl(m_file.str()));
+    
+    artificialStrings.insert(m_file, KSharedPtr<ArtificialStringData>(new ArtificialStringData(text)));
+}
+
+IndexedString InsertArtificialCodeRepresentation::file()
+{
+    return m_file;
 }
 
 InsertArtificialCodeRepresentation::~InsertArtificialCodeRepresentation() {
