@@ -47,6 +47,7 @@
 #include "specializationstore.h"
 #include "types/typeutils.h"
 #include "types/typealiastype.h"
+#include "classdeclaration.h"
 
 using namespace KTextEditor;
 
@@ -208,7 +209,7 @@ Identifier Declaration::identifier( ) const
   return d_func()->m_identifier.identifier();
 }
 
-IndexedIdentifier Declaration::indexedIdentifier( ) const
+const IndexedIdentifier& Declaration::indexedIdentifier( ) const
 {
   //ENSURE_CAN_READ Commented out for performance reasons
   return d_func()->m_identifier;
@@ -318,8 +319,10 @@ void Declaration::setAbstractType(AbstractType::Ptr type)
     //DUChain::declarationChanged(this, DUChainObserver::Addition, DUChainObserver::DataType);
 }
 
-Declaration* Declaration::specialize(IndexedInstantiationInformation /*specialization*/, const TopDUContext* /*topContext*/, int /*upDistance*/)
+Declaration* Declaration::specialize(IndexedInstantiationInformation /*specialization*/, const TopDUContext* topContext, int /*upDistance*/)
 {
+  if(!topContext)
+    return 0;
   return this;
 }
 
@@ -616,7 +619,7 @@ CodeModelItem::Kind kindForDeclaration(Declaration* decl) {
     kind = CodeModelItem::Function;
   }
 
-  if(decl->kind() == Declaration::Type && decl->type<StructureType>())
+  if(decl->kind() == Declaration::Type && (decl->type<StructureType>() || dynamic_cast<ClassDeclaration*>(decl)))
     kind = CodeModelItem::Class;
 
   if(kind == CodeModelItem::Unknown && decl->kind() == Declaration::Instance)
