@@ -320,6 +320,22 @@ public:
     m_cleanup->start();
     
     duChainDeleted = false;
+    
+    {
+      ///@todo Solve this more duchain-like
+      QFile f(globalItemRepositoryRegistry().path() + "/parsing_environment_data");
+      bool opened = f.open(QIODevice::ReadOnly);
+      ParsingEnvironmentFile::m_staticData = (StaticParsingEnvironmentData*) new char[sizeof(StaticParsingEnvironmentData)];
+      if(opened) {
+        kDebug() << "reading parsing-environment static data";
+        //Read
+        f.read((char*)ParsingEnvironmentFile::m_staticData, sizeof(StaticParsingEnvironmentData));
+      }else{
+        kDebug() << "creating new parsing-environment static data";
+        //Initialize
+        new (ParsingEnvironmentFile::m_staticData) StaticParsingEnvironmentData();
+      }
+    }
   }
   ~DUChainPrivate() {
     duChainDeleted = true;
@@ -803,6 +819,16 @@ public:
       //This must be the last step, due to the on-disk reference counting
       globalItemRepositoryRegistry().store(); //Stores all repositories
 
+      {
+        //Store the static parsing-environment file data
+        ///@todo Solve this more elegantly, using a general mechanism to store static duchain-like data
+        Q_ASSERT(ParsingEnvironmentFile::m_staticData);
+        QFile f(globalItemRepositoryRegistry().path() + "/parsing_environment_data");
+        bool opened = f.open(QIODevice::WriteOnly);
+        Q_ASSERT(opened);
+        f.write((char*)ParsingEnvironmentFile::m_staticData, sizeof(StaticParsingEnvironmentData));
+      }
+      
       if(retries) {
         doMoreCleanup(retries-1, false);
         writeLock.lock();
@@ -1169,8 +1195,8 @@ void DUChain::removeFromEnvironmentManager( TopDUContext * chain ) {
   sdDUChainPrivate->removeEnvironmentInformation(file);
 }
 
-TopDUContext* DUChain::chainForDocument(const KUrl& document) const {
-  return chainForDocument(IndexedString(document.pathOrUrl()));
+TopDUContext* DUChain::chainForDocument(const KUrl& document, bool proxyContext) const {
+  return chainForDocument(IndexedString(document.pathOrUrl()), proxyContext);
 }
 
 bool DUChain::isInMemory(uint topContextIndex) const {
@@ -1224,8 +1250,10 @@ TopDUContext* DUChain::chainForIndex(uint index) const {
   }
 }
 
-TopDUContext* DUChain::chainForDocument(const IndexedString& document) const
+TopDUContext* DUChain::chainForDocument(const KDevelop::IndexedString& document, bool proxyContext) const
 {
+  ENSURE_CHAIN_READ_LOCKED;
+  
   if(sdDUChainPrivate->m_destroyed)
     return 0;
 
@@ -1240,21 +1268,27 @@ TopDUContext* DUChain::chainForDocument(const IndexedString& document) const
 
     }*/
 
-  // Match any parsed version of this document
-  if(sdDUChainPrivate->m_chainsByUrl.contains(document))
-    return *sdDUChainPrivate->m_chainsByUrl.find(document);
-
   //Eventually load an existing chain from disk
   l.unlock();
   
   QList<ParsingEnvironmentFilePointer> list = sdDUChainPrivate->getEnvironmentInformation(document);
   
-  foreach(const ParsingEnvironmentFilePointer &file, list) {
-    if(isInMemory(file->indexedTopContext().index()))
-      return file->indexedTopContext().data();
+  foreach(const ParsingEnvironmentFilePointer &file, list)
+    if(isInMemory(file->indexedTopContext().index()) && file->isProxyContext() == proxyContext) {
+      return file->topContext();
+    }
+
+  foreach(const ParsingEnvironmentFilePointer &file, list)
+    if((proxyContext == file->isProxyContext())) {
+      return file->topContext();
+    }
+
+  //Allow selecting a top-context even if there is no ParsingEnvironmentFile
+  QList< TopDUContext* > ret = chainsForDocument(document);
+  foreach(TopDUContext* ctx, ret) {
+    if(!ctx->parsingEnvironmentFile() || (ctx->parsingEnvironmentFile()->isProxyContext() == proxyContext))
+      return ctx;
   }
-  if(!list.isEmpty())
-    return list[0]->topContext(); //Load a top-context if there is none in memory
 
   return 0;
 }
@@ -1284,12 +1318,14 @@ QList<TopDUContext*> DUChain::chainsForDocument(const IndexedString& document) c
   return chains;
 }
 
-TopDUContext* DUChain::chainForDocument( const KUrl& document, const ParsingEnvironment* environment, bool onlyProxyContexts, bool noProxyContexts ) const {
-  return chainForDocument( IndexedString(document), environment, onlyProxyContexts, noProxyContexts );
+TopDUContext* DUChain::chainForDocument( const KUrl& document, const KDevelop::ParsingEnvironment* environment, bool proxyContext ) const {
+  return chainForDocument( IndexedString(document), environment, proxyContext );
 }
 
-ParsingEnvironmentFilePointer DUChain::environmentFileForDocument( const IndexedString& document, const ParsingEnvironment* environment, bool onlyProxyContexts, bool noProxyContexts ) const {
+ParsingEnvironmentFilePointer DUChain::environmentFileForDocument( const IndexedString& document, const ParsingEnvironment* environment, bool proxyContext ) const {
 
+  ENSURE_CHAIN_READ_LOCKED;
+  
   if(sdDUChainPrivate->m_destroyed)
     return ParsingEnvironmentFilePointer();
   QList< ParsingEnvironmentFilePointer> list = sdDUChainPrivate->getEnvironmentInformation(document);
@@ -1298,7 +1334,7 @@ ParsingEnvironmentFilePointer DUChain::environmentFileForDocument( const Indexed
 
   QList< ParsingEnvironmentFilePointer>::const_iterator it = list.constBegin();
   while(it != list.constEnd()) {
-    if(*it && (*it)->matchEnvironment(environment) && (!onlyProxyContexts || (*it)->isProxyContext()) && (!noProxyContexts || !(*it)->isProxyContext())) {
+    if(*it && ((*it)->isProxyContext() == proxyContext) && (*it)->matchEnvironment(environment)) {
       return *it;
     }
     ++it;
@@ -1317,11 +1353,11 @@ ParsingEnvironmentFilePointer DUChain::environmentFileForDocument(IndexedTopDUCo
    return ParsingEnvironmentFilePointer(sdDUChainPrivate->loadInformation(topContext.index()));
 }
 
-TopDUContext* DUChain::chainForDocument( const IndexedString& document, const ParsingEnvironment* environment, bool onlyProxyContexts, bool noProxyContexts ) const {
-
+TopDUContext* DUChain::chainForDocument( const IndexedString& document, const ParsingEnvironment* environment, bool proxyContext ) const {
+  
   if(sdDUChainPrivate->m_destroyed)
     return 0;
-  ParsingEnvironmentFilePointer envFile = environmentFileForDocument(document, environment, onlyProxyContexts, noProxyContexts);
+  ParsingEnvironmentFilePointer envFile = environmentFileForDocument(document, environment, proxyContext);
   if(envFile) {
     return envFile->topContext();
   }else{
@@ -1584,7 +1620,22 @@ void DUChain::emitDeclarationSelected(DeclarationPointer decl) {
   emit declarationSelected(decl);
 }
 
-KDevelop::ReferencedTopDUContext DUChain::waitForUpdate(const KDevelop::IndexedString& document, KDevelop::TopDUContext::Features minFeatures, bool wantProxyContext) {
+TopDUContext* contentContextFromProxyContext(TopDUContext* top)
+{
+  if(!top)
+    return 0;
+  if(top->parsingEnvironmentFile() && top->parsingEnvironmentFile()->isProxyContext()) {
+    if(!top->importedParentContexts().isEmpty())
+      return top->importedParentContexts()[0].context(0)->topContext();
+    else {
+      kDebug() << "Proxy-context imports no content-context";
+      return 0;
+    }
+  } else
+    return top;
+}
+
+KDevelop::ReferencedTopDUContext DUChain::waitForUpdate(const KDevelop::IndexedString& document, KDevelop::TopDUContext::Features minFeatures, bool proxyContext) {
   Q_ASSERT(!lock()->currentThreadHasReadLock() && !lock()->currentThreadHasWriteLock());
 
   WaitForUpdate waiter;
@@ -1607,18 +1658,19 @@ KDevelop::ReferencedTopDUContext DUChain::waitForUpdate(const KDevelop::IndexedS
 //     waiter.m_wait.wait(&waiter.m_waitMutex, 10);
   }
 
-  if(!wantProxyContext) {
+  if(!proxyContext) {
     DUChainReadLocker readLock(DUChain::lock());
-    if(waiter.m_topContext && waiter.m_topContext->parsingEnvironmentFile() && waiter.m_topContext->parsingEnvironmentFile()->isProxyContext() && !waiter.m_topContext->importedParentContexts().isEmpty())
-      return waiter.m_topContext->importedParentContexts()[0].context(0)->topContext();
+    return contentContextFromProxyContext(waiter.m_topContext);
   }
 
   return waiter.m_topContext;
 }
 
 void DUChain::updateContextForUrl(const IndexedString& document, TopDUContext::Features minFeatures, QObject* notifyReady) const {
+  DUChainReadLocker lock( DUChain::lock() );
   TopDUContext* standardContext = DUChainUtils::standardContextForUrl(document.toUrl());
   if(standardContext && standardContext->parsingEnvironmentFile() && !standardContext->parsingEnvironmentFile()->needsUpdate() && standardContext->parsingEnvironmentFile()->featuresSatisfied(minFeatures)) {
+    lock.unlock();
     if(notifyReady)
     QMetaObject::invokeMethod(notifyReady, "updateReady", Qt::DirectConnection, Q_ARG(KDevelop::IndexedString, document), Q_ARG(KDevelop::ReferencedTopDUContext, ReferencedTopDUContext(standardContext)));
   }else{
