@@ -891,6 +891,32 @@ bool DUContext::findDeclarationsInternal( const SearchItem::PtrList & baseIdenti
   return true;
 }
 
+QList< QualifiedIdentifier > DUContext::fullyApplyAliases(KDevelop::QualifiedIdentifier id, const KDevelop::TopDUContext* source) const
+{
+  ENSURE_CAN_READ
+  
+  if(!source)
+    source = topContext();
+
+  SearchItem::PtrList identifiers;
+  identifiers << SearchItem::Ptr(new SearchItem(id));
+
+  const DUContext* current = this;
+  while(current) {
+    SearchItem::PtrList aliasedIdentifiers;
+    current->applyAliases(identifiers, aliasedIdentifiers, SimpleCursor::invalid(), true, false);
+    current->applyUpwardsAliases(identifiers, source);
+    
+    current = current->parentContext();
+  }
+  
+  QList<QualifiedIdentifier> ret;
+  FOREACH_ARRAY(SearchItem::Ptr item, identifiers)
+    ret += item->toList();
+  
+  return ret;
+}
+
 QList<Declaration*> DUContext::findDeclarations( const QualifiedIdentifier & identifier, const SimpleCursor & position, const AbstractType::Ptr& dataType, const TopDUContext* topContext, SearchFlags flags) const
 {
   ENSURE_CAN_READ
@@ -1320,6 +1346,14 @@ void DUContext::deleteUses()
   clearUseSmartRanges();
 }
 
+void DUContext::deleteUsesRecursively()
+{
+  deleteUses();
+  
+  FOREACH_FUNCTION(LocalIndexedDUContext childContext, d_func()->m_childContexts)
+    childContext.data(topContext())->deleteUsesRecursively();
+}
+
 bool DUContext::inDUChain() const {
   if( d_func()->m_anonymousInParent || !m_dynamicData->m_parentContext)
     return false;
@@ -1328,7 +1362,9 @@ bool DUContext::inDUChain() const {
   return top && top->inDUChain();
 }
 
-DUContext* DUContext::specialize(IndexedInstantiationInformation /*specialization*/, const TopDUContext* /*topContext*/, int /*upDistance*/) {
+DUContext* DUContext::specialize(IndexedInstantiationInformation /*specialization*/, const TopDUContext* topContext, int /*upDistance*/) {
+  if(!topContext)
+    return 0;
   return this;
 }
 
@@ -1701,7 +1737,7 @@ void DUContext::clearImportedParentContexts()
   DUCHAIN_D_DYNAMIC(DUContext);
 
   while( d->m_importedContextsSize() != 0 ) {
-    DUContext* ctx = d->m_importedContexts()[0].context(0);
+    DUContext* ctx = d->m_importedContexts()[0].context(0, false);
     if(ctx)
       ctx->m_dynamicData->removeImportedChildContext(this);
 
@@ -1901,9 +1937,9 @@ DUContext::Import::Import(const DeclarationId& id, const SimpleCursor& _position
   m_declaration = id;
 }
 
-DUContext* DUContext::Import::context(const TopDUContext* topContext) const {
+DUContext* DUContext::Import::context(const KDevelop::TopDUContext* topContext, bool instantiateIfRequired) const {
   if(m_declaration.isValid()) {
-    Declaration* decl = m_declaration.getDeclaration(topContext);
+    Declaration* decl = m_declaration.getDeclaration(topContext, instantiateIfRequired);
     if(decl)
       return decl->logicalInternalContext(topContext);
     else
