@@ -360,7 +360,7 @@ public:
 
     ///@param topContext The top-context from where to start searching. This is important to find the correct imports
     ///                  in the case of templates or similar structures.
-    DUContext* context(const TopDUContext* topContext) const;
+    DUContext* context(const TopDUContext* topContext, bool instantiateIfRequired = true) const;
 
     //Returns the top-context index, if this import is not a specialization import.
     uint topContextIndex() const {
@@ -477,7 +477,8 @@ public:
    * Retrieve the context which is specialized with the given \a specialization as seen from the given \a topContext.
    *
    * \param specialization the specialization index (see DeclarationId)
-   * \param topContext the top context to search from
+   * \param topContext the top context representing the perspective from which to specialize.
+   *                                if @p topContext is zero, only already existing specializations are returned, and if none exists, zero is returned.
    * \param upDistance upwards distance in the context-structure of the
    *                   given specialization-info. This allows specializing children.
    * */
@@ -681,10 +682,15 @@ public:
   void deleteUse(int index);
 
   /**
-   * Clear and delete all uses in this context.
+   * Clear and delete all uses in this context, including smart-ranges etc.
    */
   virtual void deleteUses();
 
+  /**
+   * Recursively delete all uses in this context and all its child-contexts
+   */
+  virtual void deleteUsesRecursively();
+  
   /**
    * Returns the smart-ranges associated to the uses
    */
@@ -780,6 +786,10 @@ struct KDEVPLATFORMLANGUAGE_EXPORT SearchItem : public KShared {
   ///Call this after parsing is finished. It will optimize the internal vectors to reduce memory-usage.
   void squeeze();
 
+  ///Returns the qualified identifier @p id with all aliases (for example namespace imports) applied
+  ///Example: If the namespace 'Foo' is imported, and id is 'Bar', then the returned list is 'Bar' and 'Foo::Bar'
+  QList<QualifiedIdentifier> fullyApplyAliases(KDevelop::QualifiedIdentifier id, const KDevelop::TopDUContext* source) const;
+  
   protected:
 
   /**
