@@ -31,6 +31,7 @@
 #include <interfaces/iuicontroller.h>
 #include <interfaces/icore.h>
 #include <interfaces/iruncontroller.h>
+#include <interfaces/ipartcontroller.h>
 #include <interfaces/context.h>
 
 #include <interfaces/contextmenuextension.h>
@@ -100,6 +101,12 @@ CvsPlugin::~CvsPlugin()
 }
 
 
+void CvsPlugin::unload()
+{
+    core()->uiController()->removeToolView( d->m_factory );
+}
+
+
 CvsProxy* CvsPlugin::proxy()
 {
     return d->m_proxy;
@@ -428,6 +435,8 @@ KDevelop::VcsJob * CvsPlugin::annotate(const KUrl & localLocation, const KDevelo
 
 KDevelop::VcsJob * CvsPlugin::resolve(const KUrl::List & localLocations, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
+    Q_UNUSED(localLocations);
+    Q_UNUSED(recursion);
     return NULL;
 }
 
@@ -456,6 +465,7 @@ KDevelop::VcsJob * CvsPlugin::import(const QString& commitMessage, const KUrl& s
 
 KDevelop::VcsJob * CvsPlugin::createWorkingCopy(const KDevelop::VcsLocation & sourceRepository, const KUrl & destinationDirectory, KDevelop::IBasicVersionControl::RecursionMode recursion)
 {
+    Q_UNUSED(recursion);
     if (!destinationDirectory.isLocalFile()
             || !sourceRepository.isValid()
             || sourceRepository.type() != KDevelop::VcsLocation::RepositoryLocation) {
