@@ -101,14 +101,19 @@ private Q_SLOTS:
     void deleted(const QString &path);
     void created(const QString &path);
 
+private:
+    /// Stops watching the given folder for changes, only useful for local files.
+    void stopWatcher(KDevelop::ProjectFolderItem* folder);
+    /// Continues watching the given folder for changes.
+    void continueWatcher(KDevelop::ProjectFolderItem* folder);
+    /// Common renaming function.
+    bool rename( KDevelop::ProjectBaseItem* item, const KUrl& source, const KUrl& destination);
+
 private:
     bool isValid( const KUrl& url, const bool isFolder, KDevelop::IProject* project,
                   const IncludeRules& rules ) const;
     QMap<KDevelop::IProject*, KDirWatch*> m_watchers;
     QMap<KIO::Job*, KDevelop::IProject*> m_jobProjects;
-
-private:
-    class GenericProjectManagerPrivate* const d;
 };
 
 #endif // KDEVGENERICIMPORTER_H
