@@ -285,7 +285,7 @@ void PatchReviewPlugin::seekHunk( bool forwards, const KUrl& fileName ) {
                     Q_ASSERT(smart);
                     QMutexLocker lock(smart->smartMutex());
 
-                    QList< KTextEditor::SmartRange* > ranges = m_highlighters[doc->url()]->ranges();
+                    const QList< KTextEditor::SmartRange* > ranges = m_highlighters[doc->url()]->ranges();
                     
                     KTextEditor::View * v = doc->textDocument() ->activeView();
                     int bestLine = -1;
@@ -351,7 +351,7 @@ void PatchReviewPlugin::addHighlighting(const KUrl& highlightFile, IDocument* do
 
             kDebug() << "highlighting file" << file << "with doc" << doc;
             
-            if ( !doc )
+            if ( !doc || !doc->textDocument() )
                 continue;
 
             removeHighlighting( file );
@@ -476,9 +476,9 @@ void PatchReviewToolView::kompareModelChanged()
     const Diff2::DiffModelList* models = m_plugin->modelList()->models();
     if ( !models )
         throw "no diff-models";
-    Diff2::DiffModelList::const_iterator it = models->begin();
+    Diff2::DiffModelList::const_iterator it = models->constBegin();
     QSet<KUrl> haveUrls;
-    while ( it != models->end() ) {
+    while ( it != models->constEnd() ) {
         Diff2::DifferenceList * diffs = ( *it ) ->differences();
         int cnt = 0;
         if ( diffs )
@@ -510,7 +510,7 @@ void PatchReviewToolView::kompareModelChanged()
     ///findProject() excludes some useless files like backups, so we can use that to sort those files to the back
     for(int withProject = 1; withProject >= 0; --withProject)
     {
-      for(QMap<KUrl, QString>::const_iterator it = additionalUrls.begin(); it != additionalUrls.end(); ++it)
+      for(QMap<KUrl, QString>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); ++it)
       {
         KUrl url = it.key();
         
@@ -745,7 +745,7 @@ void PatchHighlighter::markClicked(KTextEditor::Document* doc, KTextEditor::Mark
 
 KTextEditor::SmartRange* PatchHighlighter::rangeForMark(KTextEditor::Mark mark)
 {
-    for(QMap< KTextEditor::SmartRange*, Diff2::Difference* >::const_iterator it = m_differencesForRanges.begin(); it != m_differencesForRanges.end(); ++it) {
+    for(QMap< KTextEditor::SmartRange*, Diff2::Difference* >::const_iterator it = m_differencesForRanges.constBegin(); it != m_differencesForRanges.constEnd(); ++it) {
       if(it.key()->start().line() == mark.line)
       {
         return it.key();
@@ -790,29 +790,24 @@ bool PatchHighlighter::isRemoval(Diff2::Difference* diff)
 }
 
 
-PatchHighlighter::PatchHighlighter( const Diff2::DiffModel* model, IDocument* kdoc, PatchReviewPlugin* plugin ) throw( QString ) : m_doc( kdoc ), m_plugin(plugin) {
-//  connect( kdoc, SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
-    connect( kdoc->textDocument(), SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
-    connect( model, SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
-
-    KTextEditor::Document* doc = kdoc->textDocument();
-    if ( doc->lines() == 0 )
-        return ;
-
-    if ( !model->differences() )
+void PatchHighlighter::textInserted(KTextEditor::Document* doc, KTextEditor::Range range)
+{
+    if(range == doc->documentRange())
+    {
+      kWarning() << "re-doing";
+      //The document was loaded / reloaded
+    if ( !m_model->differences() )
         return ;
     KTextEditor::SmartInterface* smart = dynamic_cast<KTextEditor::SmartInterface*>( doc );
     if ( !smart )
-        throw QString( "no smart-interface" );
+        return;
 
     KTextEditor::MarkInterface* markIface = dynamic_cast<KTextEditor::MarkInterface*>( doc );
     if( !markIface )
-      throw QString( "no mark-interface" );
+      return;
+    
+    clear();
     
-    ///This requires the KDE 4.4 development branch from 12.8.2009
-    connect(doc, SIGNAL(markToolTipRequested(KTextEditor::Document*,KTextEditor::Mark,QPoint,bool&)), this, SLOT(markToolTipRequested(KTextEditor::Document*,KTextEditor::Mark,QPoint,bool&)));
-    connect(doc, SIGNAL(markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)), this, SLOT(markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)));
-
     QColor activeIconColor = QApplication::palette().color(QPalette::Active, QPalette::Highlight);
     QColor inActiveIconColor = QApplication::palette().color(QPalette::Active, QPalette::Base);
     
@@ -843,7 +838,9 @@ PatchHighlighter::PatchHighlighter( const Diff2::DiffModel* model, IDocument* kd
 
     KTextEditor::SmartRange* topRange = smart->newSmartRange(doc->documentRange(), 0, KTextEditor::SmartRange::ExpandLeft | KTextEditor::SmartRange::ExpandRight);
 
-    for ( Diff2::DifferenceList::const_iterator it = model->differences() ->begin(); it != model->differences() ->end(); ++it ) {
+    topRange->addWatcher(this);
+    
+    for ( Diff2::DifferenceList::const_iterator it = m_model->differences() ->constBegin(); it != m_model->differences() ->constEnd(); ++it ) {
         Diff2::Difference* diff = *it;
         int line, lineCount;
         Diff2::DifferenceStringList lines ;
@@ -865,6 +862,7 @@ PatchHighlighter::PatchHighlighter( const Diff2::DiffModel* model, IDocument* kd
         if ( endC.isValid() && c.isValid() ) {
             KTextEditor::SmartRange * r = smart->newSmartRange( c, endC );
             r->setParentRange(topRange);
+            r->addWatcher(this);
             
             m_differencesForRanges[r] = *it;
 
@@ -875,6 +873,24 @@ PatchHighlighter::PatchHighlighter( const Diff2::DiffModel* model, IDocument* kd
     m_ranges << topRange;
 
     smart->addHighlightToDocument(topRange);
+    }
+}
+
+PatchHighlighter::PatchHighlighter( const Diff2::DiffModel* model, IDocument* kdoc, PatchReviewPlugin* plugin ) throw( QString ) : m_doc( kdoc ), m_plugin(plugin), m_model(model) {
+//  connect( kdoc, SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
+    connect( kdoc->textDocument(), SIGNAL(textInserted(KTextEditor::Document*,KTextEditor::Range)), this, SLOT(textInserted(KTextEditor::Document*,KTextEditor::Range)) );
+    connect( kdoc->textDocument(), SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
+    connect( model, SIGNAL( destroyed( QObject* ) ), this, SLOT( documentDestroyed() ) );
+
+    KTextEditor::Document* doc = kdoc->textDocument();
+    if ( doc->lines() == 0 )
+        return ;
+
+    ///This requires the KDE 4.4 development branch from 12.8.2009
+    connect(doc, SIGNAL(markToolTipRequested(KTextEditor::Document*,KTextEditor::Mark,QPoint,bool&)), this, SLOT(markToolTipRequested(KTextEditor::Document*,KTextEditor::Mark,QPoint,bool&)));
+    connect(doc, SIGNAL(markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)), this, SLOT(markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&)));
+    
+    textInserted(kdoc->textDocument(), kdoc->textDocument()->documentRange());
 }
 
 void PatchHighlighter::removeLineMarker(KTextEditor::SmartRange* range, Diff2::Difference* difference)
@@ -968,7 +984,7 @@ void PatchHighlighter::addLineMarker(KTextEditor::SmartRange* range, Diff2::Diff
     }
 }
 
-PatchHighlighter::~PatchHighlighter()
+void PatchHighlighter::clear()
 {
     KTextEditor::SmartInterface* smart = dynamic_cast<KTextEditor::SmartInterface*>( m_doc->textDocument() );
     if ( !smart )
@@ -990,10 +1006,16 @@ PatchHighlighter::~PatchHighlighter()
     
     QMutexLocker lock(smart->smartMutex());
 
-    for ( QSet<KTextEditor::SmartRange*>::iterator it = m_ranges.begin(); it != m_ranges.end(); ++it )
-        delete *it;
+    while(!m_ranges.isEmpty())
+      delete *m_ranges.begin();
 
-    m_ranges.clear();
+    Q_ASSERT(m_ranges.isEmpty());
+    Q_ASSERT(m_differencesForRanges.isEmpty());
+}
+
+PatchHighlighter::~PatchHighlighter()
+{
+    clear();
 }
 
 IDocument* PatchHighlighter::doc() {
