@@ -71,16 +71,19 @@ private:
     KTextEditor::SmartRange* rangeForMark(KTextEditor::Mark mark);
 
     virtual void rangeDeleted(KTextEditor::SmartRange* range);
+    void clear();
     QSet<KTextEditor::SmartRange*> m_ranges;
     QMap<KTextEditor::SmartRange*, Diff2::Difference*> m_differencesForRanges;
     KDevelop::IDocument* m_doc;
     PatchReviewPlugin* m_plugin;
+    const Diff2::DiffModel* m_model;
 public slots:
     void markToolTipRequested(KTextEditor::Document*,KTextEditor::Mark,QPoint,bool&);
     void showToolTipForMark(QPoint arg1, KTextEditor::SmartRange* arg2, QPair< int, int > highlightMark = qMakePair(-1, -1));
     bool isRemoval(Diff2::Difference*);
     bool isInsertion(Diff2::Difference*);
     void markClicked(KTextEditor::Document*,KTextEditor::Mark,bool&);
+    void textInserted(KTextEditor::Document*,KTextEditor::Range);
 };
 
 class DiffSettings;
