@@ -22,7 +22,6 @@
 #include "projectmanagerview.h"
 
 #include <QtCore/QDebug>
-#include <QtCore/QTimer>
 #include <QtGui/QHeaderView>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHBoxLayout>
@@ -113,31 +112,7 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
              SLOT(updateSyncAction()));
     connect( KDevelop::ICore::self()->documentController(), SIGNAL(documentOpened(KDevelop::IDocument*) ),
              SLOT(updateSyncAction()));
-             
-    connect( KDevelop::ICore::self()->projectController(), SIGNAL(projectAboutToBeOpened(KDevelop::IProject*)),
-             SLOT(projectToBeOpened()) );
-    connect( KDevelop::ICore::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
-             SLOT(projectOpened()) );
     selectionChanged();
-    // Update the progress-state, but do so in a second so we
-    // can be sure the button has been created
-    QTimer::singleShot( 1000, this, SLOT(projectToBeOpened()) );
-}
-
-void ProjectManagerView::projectOpened()
-{
-    if( m_plugin->numProjectsBeingOpened() == 0 )
-    {
-        emit hideProgressIndicator();
-    }
-}
-
-void ProjectManagerView::projectToBeOpened()
-{
-    if( m_plugin->numProjectsBeingOpened() != 0 )
-    {
-        emit showProgressIndicator();
-    }
 }
 
 void ProjectManagerView::selectionChanged()
