@@ -34,6 +34,7 @@
 #include <KTemporaryFile>
 
 #include <project/projectmodel.h>
+#include <project/projectbuildsetmodel.h>
 #include <interfaces/icore.h>
 #include <interfaces/iproject.h>
 #include <project/interfaces/iprojectfilemanager.h>
@@ -48,7 +49,6 @@
 #include <interfaces/iselectioncontroller.h>
 
 #include "projectmanagerview.h"
-#include "projectbuildsetmodel.h"
 #include "builditembuilderjob.h"
 
 using namespace KDevelop;
@@ -74,11 +74,6 @@ class KDevProjectManagerViewFactory: public KDevelop::IToolViewFactory
             return "org.kdevelop.ProjectsView";
         }
         
-        virtual bool viewsWantProgressIndicator() const 
-        {
-            return true;
-        }
-
     private:
         ProjectManagerViewPlugin *mplugin;
 };
@@ -96,27 +91,11 @@ public:
     KAction* m_clean;
     KAction* m_configure;
     KAction* m_prune;
-    ProjectBuildSetModel* buildSet;
 };
 
 ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVariantList& )
-        : IPlugin( ProjectManagerFactory::componentData(), parent ), d(new ProjectManagerViewPluginPrivate),
-        projectsBeingOpened( 0 )
+        : IPlugin( ProjectManagerFactory::componentData(), parent ), d(new ProjectManagerViewPluginPrivate)
 {
-    d->buildSet = new ProjectBuildSetModel( this );
-
-    connect( core()->projectController(), SIGNAL( projectAboutToBeOpened( KDevelop::IProject* ) ),
-             SLOT( projectToBeOpened() ) );
-    connect( core()->projectController(), SIGNAL( projectOpened( KDevelop::IProject* ) ),
-             SLOT( projectOpened() ) );
-    connect( core()->projectController(), SIGNAL( projectOpened( KDevelop::IProject* ) ),
-             d->buildSet, SLOT( loadFromProject( KDevelop::IProject* ) ) );
-
-    connect( core()->projectController(), SIGNAL( projectClosing( KDevelop::IProject* ) ),
-             d->buildSet, SLOT( saveToProject( KDevelop::IProject* ) ) );
-    connect( core()->projectController(), SIGNAL( projectClosed( KDevelop::IProject* ) ),
-             d->buildSet, SLOT( projectClosed( KDevelop::IProject* ) ) );
-
     d->m_buildAll = new KAction( i18n("Build all Projects"), this );
     d->m_buildAll->setIcon(KIcon("run-build"));
     connect( d->m_buildAll, SIGNAL(triggered()), this, SLOT(buildAllProjects()) );
@@ -152,29 +131,14 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     core()->uiController()->addToolView( i18n("Projects"), d->factory );
     connect( core()->selectionController(), SIGNAL(selectionChanged(KDevelop::Context*)),
              SLOT(updateActionState(KDevelop::Context*)));
-    connect( d->buildSet, SIGNAL(rowsInserted(const QModelIndex&, int, int)),
+    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsInserted(const QModelIndex&, int, int)),
              SLOT(updateFromBuildSetChange()));
-    connect( d->buildSet, SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
+    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(rowsRemoved(const QModelIndex&, int, int)),
              SLOT(updateFromBuildSetChange()));
-    connect( d->buildSet, SIGNAL(modelReset()),
+    connect( ICore::self()->projectController()->buildSetModel(), SIGNAL(modelReset()),
              SLOT(updateFromBuildSetChange()));
 }
 
-void ProjectManagerViewPlugin::projectToBeOpened()
-{
-    projectsBeingOpened++;
-}
-
-void ProjectManagerViewPlugin::projectOpened()
-{
-    projectsBeingOpened--;
-}
-
-int ProjectManagerViewPlugin::numProjectsBeingOpened()
-{
-    return projectsBeingOpened;
-}
-
 void ProjectManagerViewPlugin::updateFromBuildSetChange()
 {
     updateActionState( core()->selectionController()->currentSelection() );
@@ -182,7 +146,7 @@ void ProjectManagerViewPlugin::updateFromBuildSetChange()
 
 void ProjectManagerViewPlugin::updateActionState( KDevelop::Context* ctx )
 {
-    bool isEmpty = d->buildSet->items().isEmpty();
+    bool isEmpty = ICore::self()->projectController()->buildSetModel()->items().isEmpty();
     if( isEmpty ) 
     {
         isEmpty = !ctx || ctx->type() != Context::ProjectItemContext || dynamic_cast<ProjectItemContext*>( ctx )->items().isEmpty();
@@ -253,13 +217,13 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
         if ( !closeProjectsAdded && prjitem && prjitem->isProjectRoot() )
         {
             KAction* close = new KAction( i18np( "Close Project", "Close Projects", items.count() ), this );
-            close->setIcon(KIcon("project-close"));
+            close->setIcon(KIcon("project-development-close"));
             connect( close, SIGNAL(triggered()), this, SLOT(closeProjects()) );
             menuExt.addAction( ContextMenuExtension::ProjectGroup, close );
             closeProjectsAdded = true;
         }
 
-        if ( !folderItemsAdded && item->folder() )
+        if ( !folderItemsAdded && prjitem )
         {
             folderItemsAdded = true;
             KAction* action = new KAction( i18n( "Create File" ), this );
@@ -304,7 +268,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
             menuExt.addAction( ContextMenuExtension::FileGroup, action );
         }
         
-        if( !renameAdded && (item->file() || item->folder()) )
+        if( !renameAdded && (item->file() || item->folder()) && item->parent() )
         {
             renameAdded = true;
             KAction* action = new KAction( i18n( "Rename" ), this );
@@ -395,9 +359,9 @@ void ProjectManagerViewPlugin::buildAllProjects()
 void ProjectManagerViewPlugin::runBuilderJob( KDevelop::BuilderJob::BuildType t )
 {
     QList<ProjectBaseItem*> items;
-    if( !d->buildSet->items().isEmpty() )
+    if( !ICore::self()->projectController()->buildSetModel()->items().isEmpty() )
     {
-        ICore::self()->runController()->registerJob( new BuildItemBuilderJob( t, d->buildSet->items() ) );
+        ICore::self()->runController()->registerJob( new BuildItemBuilderJob( t, ICore::self()->projectController()->buildSetModel()->items() ) );
     } else
     {
         KDevelop::ProjectItemContext* ctx = dynamic_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
@@ -430,16 +394,11 @@ void ProjectManagerViewPlugin::buildProjectItems()
     runBuilderJob( KDevelop::BuilderJob::Build );
 }
 
-ProjectBuildSetModel* ProjectManagerViewPlugin::buildSet()
-{
-    return d->buildSet;
-}
-
 void ProjectManagerViewPlugin::addItemsFromContextMenuToBuildset( )
 {
     foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
     {
-        buildSet()->addProjectItem( item );
+        ICore::self()->projectController()->buildSetModel()->addProjectItem( item );
     }
 }
 
@@ -535,41 +494,66 @@ void ProjectManagerViewPlugin::removeFileFromContextMenu()
 void ProjectManagerViewPlugin::renameItemFromContextMenu()
 {
     QWidget* window=ICore::self()->uiController()->activeMainWindow()->window();
-    
+
     foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
     {
         KDevelop::ProjectFileItem* file=item->file();
         KDevelop::ProjectFolderItem* folder=item->folder();
-        
-        if(file) {
-            //Change QInputDialog->KFileSaveDialog?
-            QString name = QInputDialog::getText( window, i18n("Rename File"), i18n("New name for '%1'", item->text()) );
-            if (!name.isEmpty()) {
-                KUrl url = file->url().upUrl();
-                url.addPath( name );
-                
-                KIO::CopyJob* job=KIO::move(file->url(), url);
-                if(!KIO::NetAccess::synchronousRun(job, window)) {
-                    KMessageBox::error( window, i18n("Cannot rename '%1'.", file->url().prettyUrl()) );
-                    continue;
-                }
-                item->project()->projectFileManager()->renameFile(file, url);
+
+        if ((!file && !folder) || !item->parent()) {
+            continue;
+        }
+
+        const KUrl src = file ? file->url() : folder->url();
+
+        //Change QInputDialog->KFileSaveDialog?
+        QString name = QInputDialog::getText(
+            window, file ? i18n("Rename File") : i18n("Rename Folder"),
+            i18n("New name for '%1'", item->text()),
+            QLineEdit::Normal, item->text()
+        );
+
+        if (!name.isEmpty() && name != item->text()) {
+            KUrl dest = src.upUrl();
+            dest.addPath( name );
+            if ( dest.upUrl() != src.upUrl() ) {
+                KMessageBox::error( window,
+                    i18n("Cannot rename '%1' to '%2'.", src.fileName(), name)
+                );
+                return;
             }
-        } else if(folder) {
-            //Change QInputDialog->KFileSaveDialog?
-            QString name = QInputDialog::getText( window, i18n("Rename Folder"), i18n("New name for '%1'", item->text()) );
-            if (!name.isEmpty()) {
-                KUrl url = folder->url().upUrl();
-                url.addPath( name );
-                
-                KIO::CopyJob* job=KIO::move(folder->url(), url);
-                if(!KIO::NetAccess::synchronousRun(job, window)) {
-                    KMessageBox::error( window, i18n("Cannot rename '%1'.", folder->url().prettyUrl()) );
-                    continue;
-                }
-                item->project()->projectFileManager()->renameFolder(folder, url);
+
+            KIO::UDSEntry entry;
+
+            if ( KIO::NetAccess::stat(dest, entry, window) ) {
+                if ( entry.isDir() ) {
+                    // never overwrite folders
+                    KMessageBox::error( window,
+                        i18n("Cannot rename '%1' to '%2':\nThere exists a folder with that name.",
+                             src.fileName(), dest.fileName())
+                    );
+                    return;
+                } else if ( folder ) {
+                    // cannot overwrite file with folder
+                    KMessageBox::error( window,
+                        i18n("Cannot rename folder '%1' to '%2':\nThere exists a file with that name.",
+                             src.fileName(), dest.fileName())
+                    );
+                    return;
+                } // else KIO asks for renaming the file
+            }
+
+            bool ret;
+            if (file) {
+                ret = item->project()->projectFileManager()->renameFile(file, dest);
+            } else {
+                ret = item->project()->projectFileManager()->renameFolder(folder, dest);
+            }
+            if(!ret) {
+                KMessageBox::error( window,
+                    i18n("Could not rename '%1'.", src.fileName())
+                );
             }
-            
         }
     }
 }
