@@ -44,14 +44,15 @@ public:
      */
     void createNewRepository(SnippetRepository* parent, const QString& name, const QString& dir);
 
-    /**
-     *
-     */
-    void remove(SnippetRepository* repo);
-
     void load(KConfigGroup config);
     void save(KConfigGroup config);
 
+public slots:
+    /**
+     * Removes the repository from the model and deletes it.
+     */
+    void remove( SnippetRepository* repo );
+
 private:
     SnippetStore();
     virtual Qt::ItemFlags flags (const QModelIndex & index) const;
