@@ -242,7 +242,7 @@ KDevelop::VcsRevision SvnInternalDiffJob::pegRevision() const
 }
 
 SvnDiffJob::SvnDiffJob( KDevSvnPlugin* parent )
-    : SvnJobBase( parent )
+    : SvnJobBase( parent, KDevelop::OutputJob::Silent )
 {
     setType( KDevelop::VcsJob::Add );
     m_job = new SvnInternalDiffJob( this );
