@@ -104,7 +104,26 @@ struct DocumentControllerPrivate {
     }
     void chooseDocument()
     {
-        controller->openDocument(KUrl());
+
+        KUrl dir;
+        if( controller->activeDocument() )
+        {
+            dir = KUrl( controller->activeDocument()->url().directory() );
+        }else
+        {
+            dir = KGlobal::config()->group("Open File").readEntry( "Last Open File Directory", Core::self()->projectController()->projectsBaseDirectory() );
+        }
+
+        KEncodingFileDialog::Result res = KEncodingFileDialog::getOpenUrlsAndEncoding( controller->encoding(), dir.url(), i18n( "*|Text File\n" ),
+                                    Core::self()->uiControllerInternal()->defaultMainWindow(),
+                                    i18n( "Open File" ) );
+        if( !res.URLs.isEmpty() ) {
+            QString encoding = res.encoding;
+            foreach( KUrl u, res.URLs ) {
+                openDocumentInternal(u, QString(), KTextEditor::Range::invalid(), encoding  );
+            }
+        }
+        
     }
 
     void changeDocumentUrl(KDevelop::IDocument* document)
@@ -135,7 +154,7 @@ struct DocumentControllerPrivate {
     }
 
     IDocument* openDocumentInternal( const KUrl & inputUrl, const QString& prefName = QString(),
-        const KTextEditor::Range& range = KTextEditor::Range::invalid(),
+        const KTextEditor::Range& range = KTextEditor::Range::invalid(), const QString& encoding = "",
         DocumentController::DocumentActivationParams activationParams = 0 )
     {
         IDocument* previousActiveDocument = controller->activeDocument();
@@ -145,10 +164,10 @@ struct DocumentControllerPrivate {
         
 
         UiController *uiController = Core::self()->uiControllerInternal();
-        Sublime::Area *area = uiController->activeArea();
 
+        QString _encoding = encoding;
+        
         KUrl url = inputUrl;
-        QString encoding = "";
 
         if ( url.isEmpty() && (!activationParams.testFlag(IDocumentController::DoNotCreateView)) )
         {
@@ -166,7 +185,7 @@ struct DocumentControllerPrivate {
                                         i18n( "Open File" ) );
             if( !res.URLs.isEmpty() )
                 url = res.URLs.first();
-            encoding = res.encoding;
+            _encoding = res.encoding;
         }
         if ( url.isEmpty() )
             //still no url
@@ -238,7 +257,7 @@ struct DocumentControllerPrivate {
                     doc = new PartDocument(url, Core::self(), prefName);
                 } else  if ( Core::self()->partControllerInternal()->isTextType(mimeType)) 
                 {
-                    doc = new TextDocument(url, Core::self(), encoding);
+                    doc = new TextDocument(url, Core::self(), _encoding);
                 } else if( Core::self()->partControllerInternal()->canCreatePart(url) ) 
                 {
                     doc = new PartDocument(url, Core::self());
@@ -246,7 +265,7 @@ struct DocumentControllerPrivate {
                 {
                     int openAsText = KMessageBox::questionYesNo(0, i18n("KDevelop could not find the editor for file '%1'.\nDo you want to open it as plain text?", url.fileName()), i18n("Could Not Find Editor"));
                     if (openAsText == KMessageBox::Yes)
-                        doc = new TextDocument(url, Core::self(), encoding);
+                        doc = new TextDocument(url, Core::self(), _encoding);
                     else
                         return 0;
                 }
@@ -435,7 +454,7 @@ void DocumentController::setupActions()
     action = ac->addAction( "file_open" );
     action->setIcon(KIcon("document-open"));
     action->setShortcut( Qt::CTRL + Qt::Key_O );
-    action->setText(i18n( "&Open File..." ) );
+    action->setText(i18n( "&Open..." ) );
     connect( action, SIGNAL( triggered( bool ) ), SLOT( chooseDocument() ) );
     action->setToolTip( i18n( "Open file" ) );
     action->setWhatsThis( i18n( "<b>Open file</b><p>Opens a file for editing.</p>" ) );
@@ -464,7 +483,7 @@ void DocumentController::setupActions()
     action = d->close = ac->addAction( "file_close" );
     action->setIcon(KIcon("window-close"));
     action->setShortcut( Qt::CTRL + Qt::Key_W );
-    action->setText( i18n( "&Close File" ) );
+    action->setText( i18n( "&Close" ) );
     connect( action, SIGNAL( triggered( bool ) ), SLOT( fileClose() ) );
     action->setToolTip( i18n( "Close File" ) );
     action->setWhatsThis( i18n( "<b>Close File</b><p>Closes current file.</p>" ) );
@@ -519,7 +538,7 @@ IDocument* DocumentController::openDocument( const KUrl & inputUrl,
         const KTextEditor::Range& range,
         DocumentActivationParams activationParams)
 {
-    return d->openDocumentInternal( inputUrl, "", range, activationParams );
+    return d->openDocumentInternal( inputUrl, "", range, "", activationParams );
 }
 
 
