@@ -81,15 +81,15 @@ protected:
     virtual void initialize();
     virtual void cleanup();
     virtual void initializeStatusBar();
+    void dragEnterEvent( QDragEnterEvent* );
+    void dropEvent( QDropEvent* );
 
 protected Q_SLOTS:
     virtual void tabContextMenuRequested(Sublime::View* , KMenu* );
     virtual void dockBarContextMenuRequested(Qt::DockWidgetArea, const QPoint&);
 
 private Q_SLOTS:
-    void documentActivated( KDevelop::IDocument* document );
-    void documentStateChanged( KDevelop::IDocument* document );
-    void documentClosed( KDevelop::IDocument* document );
+    void updateCaption();
 
 private:
     class MainWindowPrivate *d;
