@@ -104,9 +104,9 @@ public Q_SLOTS:
 
     bool applicationQuitRequested() const;
 
-    void configureSessions();
     void configureNotifications();
     void showAboutPlatform();
+    void showLoadedPlugins();
 
     void toggleArea(bool b);
     void showErrorMessage(QString message, int timeout);
