@@ -49,13 +49,16 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/iplugin.h>
 #include <interfaces/isession.h>
 #include <interfaces/idebugcontroller.h>
+#include <interfaces/idocumentationcontroller.h>
 
 #include <kross/krossplugin.h>
 
 #include "mainwindow.h"
 #include "core.h"
 #include "shellextension.h"
-#include <interfaces/idocumentationcontroller.h>
+#include "runcontroller.h"
+#include "debugcontroller.h"
+#include "documentationcontroller.h"
 
 namespace KDevelop
 {
@@ -589,8 +592,9 @@ QList<ContextMenuExtension> PluginController::queryPluginsForContextMenuExtensio
         IPlugin* plug = d->loadedPlugins[info];
         exts << plug->contextMenuExtension( context );
     }
-    exts << ICore::self()->debugController()->contextMenuExtension( context );
-    exts << ICore::self()->documentationController()->contextMenuExtension( context );
+    exts << Core::self()->debugControllerInternal()->contextMenuExtension( context );
+    exts << Core::self()->documentationControllerInternal()->contextMenuExtension( context );
+    exts << Core::self()->runControllerInternal()->contextMenuExtension( context );
     return exts;
 }
 
