@@ -57,6 +57,7 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/iselectioncontroller.h>
 #include <project/interfaces/iprojectfilemanager.h>
 #include <project/projectmodel.h>
+#include <project/projectbuildsetmodel.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <language/backgroundparser/backgroundparser.h>
 
@@ -71,14 +72,16 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/iruncontroller.h>
 #include <language/backgroundparser/parseprojectjob.h>
 #include <kio/job.h>
+#include "sessioncontroller.h"
+#include "session.h"
 
 namespace KDevelop
 {
 
-bool reopenProjectsOnStartup()
+bool addProjectsToBuildset()
 {
     KConfigGroup group = Core::self()->activeSession()->config()->group( "Project Manager" );
-    return group.readEntry( "Reopen Projects On Startup", false );
+    return group.readEntry( "Automatically Add Projects to Buildset", true );
 }
 
 bool parseAllProjectSources()
@@ -98,17 +101,18 @@ public:
     ProjectModel* model;
     QItemSelectionModel* selectionModel;
     QMap<IProject*, QPointer<KSettings::Dialog> > m_cfgDlgs;
-    QPointer<KAction> m_closeAllProjects;
     QPointer<KAction> m_closeProject;
     QPointer<KAction> m_openConfig;
     IProjectDialogProvider* dialog;
     QList<KUrl> m_currentlyOpening; // project-file urls that are being opened
     IProject* m_configuringProject;
     ProjectController* q;
+    ProjectBuildSetModel* buildset;
     bool m_foundProjectFile; //Temporary flag used while searching the hierarchy for a project file
+    bool m_cleaningUp; //Temporary flag enabled while destroying the project-controller
 
     ProjectControllerPrivate( ProjectController* p )
-        : m_core(0), model(0), selectionModel(0), dialog(0), m_configuringProject(0), q(p), m_foundProjectFile(false)
+        : m_core(0), model(0), selectionModel(0), dialog(0), m_configuringProject(0), q(p), m_foundProjectFile(false), m_cleaningUp(false)
     {
     }
 
@@ -324,6 +328,14 @@ ProjectController::ProjectController( Core* core )
     setObjectName("ProjectController");
     d->m_core = core;
     d->model = new ProjectModel();
+    d->buildset = new ProjectBuildSetModel( this );
+    connect( this, SIGNAL( projectOpened( KDevelop::IProject* ) ),
+             d->buildset, SLOT( loadFromProject( KDevelop::IProject* ) ) );
+    connect( this, SIGNAL( projectClosing( KDevelop::IProject* ) ),
+             d->buildset, SLOT( saveToProject( KDevelop::IProject* ) ) );
+    connect( this, SIGNAL( projectClosed( KDevelop::IProject* ) ),
+             d->buildset, SLOT( projectClosed( KDevelop::IProject* ) ) );
+
     d->selectionModel = new QItemSelectionModel(d->model);
     if(!(Core::self()->setupFlags() & Core::NoUi)) setupActions();
 
@@ -355,14 +367,6 @@ void ProjectController::setupActions()
 //    action->setWhatsThis( i18n( "<b>Close project</b><p>Closes the current project." ) );
 //    action->setEnabled( false );
 
-    d->m_closeAllProjects = action = ac->addAction( "project_close_all" );
-    action->setText( i18n( "Close All Projects" ) );
-    connect( action, SIGNAL( triggered( bool ) ), SLOT( closeAllProjects() ) );
-    action->setToolTip( i18n( "Close all currently open projects" ) );
-    action->setWhatsThis( i18n( "<b>Close all projects</b><p>Closes all of the currently open projects.</p>" ) );
-    action->setEnabled( false );
-    action->setIcon(KIcon("project-development-close-all"));
-
     d->m_closeProject = action = ac->addAction( "project_close" );
     connect( action, SIGNAL( triggered( bool ) ), SLOT( closeSelectedProjects() ) );
     action->setText( i18n( "Close Project(s)" ) );
@@ -404,29 +408,24 @@ ProjectController::~ProjectController()
 
 void ProjectController::cleanup()
 {
+    d->m_cleaningUp = true;
+    
     KSharedConfig::Ptr config = Core::self()->activeSession()->config();
     KConfigGroup group = config->group( "General Options" );
 
-    KUrl::List openProjects;
-
     foreach( IProject* project, d->m_projects ) {
-        openProjects.append(project->projectFileUrl());
         closeProject( project );
     }
-
-    group.writeEntry( "Open Projects", openProjects.toStringList() );
 }
 
 void ProjectController::initialize()
 {
-    if (reopenProjectsOnStartup()) {
-        KSharedConfig::Ptr config = Core::self()->activeSession()->config();
-        KConfigGroup group = config->group( "General Options" );
-        KUrl::List openProjects = group.readEntry( "Open Projects", QStringList() );
+    KSharedConfig::Ptr config = Core::self()->activeSession()->config();
+    KConfigGroup group = config->group( "General Options" );
+    KUrl::List openProjects = group.readEntry( "Open Projects", QStringList() );
 
-        foreach (const KUrl& url, openProjects)
-            openProject(url);
-    }
+    foreach (const KUrl& url, openProjects)
+        openProject(url);
 
     connect( Core::self()->selectionController(), SIGNAL(selectionChanged(KDevelop::Context*)),
              SLOT(updateActionStates(KDevelop::Context*)) );
@@ -529,6 +528,35 @@ void ProjectController::openProject( const KUrl &projectFile )
 {
     KUrl url = projectFile;
 
+    if(!Core::self()->sessionController()->activeSession()->containedProjects().contains(url))
+    {
+        foreach( const Session* session, Core::self()->sessionController()->sessions())
+        {
+            if(session->containedProjects().contains(url))
+            {
+                int res = KMessageBox::questionYesNo(Core::self()->uiControllerInternal()->activeMainWindow(),
+                                i18n("The project you are opening is part of the session %1, do you want to open the session instead?", session->description()));
+                if(res == KMessageBox::Yes)
+                {
+                    Core::self()->sessionController()->loadSession(session->id().toString());
+                    
+#if 0
+                    ///@todo Think about this! Problem: The session might already contain files, the debugger might be active, etc.
+                    //If this session is empty, close it
+                    if(Core::self()->sessionController()->activeSession()->description().isEmpty())
+                    {
+                        //Terminate this instance of kdevelop if the user agrees
+                        foreach(Sublime::MainWindow* window, Core::self()->uiController()->controller()->mainWindows())
+                            window->close();
+                    }
+#endif
+                    
+                    return;
+                }
+            }
+        }
+    }
+    
     if ( url.isEmpty() )
     {
         url = d->dialog->askProjectConfigLocation();
@@ -578,7 +606,6 @@ void ProjectController::openProject( const KUrl &projectFile )
     }
 
     d->m_currentlyOpening << url;
-    d->m_closeAllProjects->setEnabled(true);
     return;
 }
 
@@ -595,7 +622,8 @@ void ProjectController::projectImportingFinished( IProject* project )
     d->m_projectPlugins.insert( project, pluglist );
     d->m_projects.append( project );
 
-    d->saveListOfOpenedProjects();
+    if(!Core::self()->sessionController()->activeSession()->containedProjects().contains(project->projectFileUrl()))
+        d->saveListOfOpenedProjects();
     
 //     KActionCollection * ac = d->m_core->uiController()->defaultMainWindow()->actionCollection();
 //     QAction * action;
@@ -613,6 +641,24 @@ void ProjectController::projectImportingFinished( IProject* project )
     d->m_currentlyOpening.removeAll(project->projectFileUrl());
     emit projectOpened( project );
 
+    if( addProjectsToBuildset() )
+    {
+        // Add project to buildset, but only if there is no item for that
+        // project yet.
+        bool found = false;
+        foreach( BuildItem bi, d->buildset->items() )
+        {
+            if( bi.itemProject() == project->name() )
+            {
+                found = true;
+            }
+        }
+        if( !found )
+        {
+            d->buildset->addProjectItem( project->projectItem() );
+        }
+    }
+    
     if (parseAllProjectSources())
     {
         KJob* parseProjectJob = new KDevelop::ParseProjectJob(project);
@@ -676,18 +722,22 @@ void ProjectController::initializePluginCleanup(IProject* proj)
     // as we're being called by the view part and it gets deleted when we unload the plugin(s)
     // TODO: find a better place to unload
     connect(proj, SIGNAL(destroyed(QObject*)), this, SLOT(unloadAllProjectPlugins()));
-    if (d->m_closeAllProjects)
-    {
-        d->m_closeAllProjects->setEnabled(false);
-    }
 }
 
-void ProjectController::closeProject(IProject* proj)
+void ProjectController::closeProject(IProject* proj_)
 {
-    if(!proj || d->m_projects.indexOf(proj) == -1)
+    if(!proj_ || d->m_projects.indexOf(proj_) == -1)
     {
         return;
     }
+    
+    Project* proj = dynamic_cast<KDevelop::Project*>( proj_ );
+    if( !proj ) 
+    {
+        kWarning() << "Unknown Project subclass found!";
+        return;
+    }
+    
     d->m_projects.removeAll(proj);
     emit projectClosing(proj);
     //Core::self()->saveSettings();     // The project file is being closed.
@@ -701,7 +751,10 @@ void ProjectController::closeProject(IProject* proj)
     {
         initializePluginCleanup(proj);
     }
-    d->saveListOfOpenedProjects();
+    
+    if(!d->m_cleaningUp)
+        d->saveListOfOpenedProjects();
+    
     emit projectClosed(proj);
     return;
 }
@@ -744,16 +797,6 @@ void ProjectController::addProject(IProject* project)
     d->m_projects.append( project );
 }
 
-
-
-void ProjectController::closeAllProjects()
-{
-    foreach (IProject* project, projects())
-    {
-        closeProject(project);
-    }
-}
-
 QItemSelectionModel* ProjectController::projectSelectionModel()
 {
     return d->selectionModel;
@@ -788,7 +831,10 @@ QString ProjectController::prettyFileName(KUrl url, FormattingOptions format) co
         } else {
             prefixText = project->name() + '/';
         }
-        prefixText += project->relativeUrl(url.upUrl()).path(KUrl::AddTrailingSlash);
+        QString relativePath = project->relativeUrl(url.upUrl()).path(KUrl::AddTrailingSlash);;
+        if(relativePath.startsWith("./"))
+            relativePath = relativePath.mid(2);
+        prefixText += relativePath;
     }
     if (format == FormatHtml) {
         return prefixText + "<b>" + url.fileName() + "</b>";
@@ -797,6 +843,12 @@ QString ProjectController::prettyFileName(KUrl url, FormattingOptions format) co
     }
 }
 
+
+ProjectBuildSetModel* ProjectController::buildSetModel()
+{
+    return d->buildset;
+}
+
 }
 
 #include "projectcontroller.moc"
