@@ -65,6 +65,7 @@ public:
     virtual int projectCount() const;
     virtual QList<IProject*> projects() const;
 
+    virtual ProjectBuildSetModel* buildSetModel();
     virtual ProjectModel* projectModel();
     virtual QItemSelectionModel* projectSelectionModel();
     virtual IProject* findProjectByName( const QString& name );
@@ -83,7 +84,6 @@ public Q_SLOTS:
     virtual void openProject( const KUrl &KDev4ProjectFile = KUrl() );
     void projectImportingFinished( IProject* );
     virtual void closeProject( IProject* );
-    virtual void closeAllProjects();
     virtual void configureProject( IProject* );
     void eventuallyOpenProjectFile(KIO::Job*,KIO::UDSEntryList);
     void openProjectForUrlSlot(bool);
