@@ -82,12 +82,42 @@ Session::~Session()
     delete d;
 }
 
-
 QString Session::name() const
 {
     return d->config->group("").readEntry( cfgSessionNameEntry, "" );
 }
 
+KUrl::List Session::containedProjects() const
+{
+    return d->config->group( "General Options" ).readEntry( "Open Projects", QStringList() );
+}
+
+QString Session::description() const
+{
+    QString ret = name();
+    
+    KUrl::List openProjects = containedProjects();
+
+    if(!openProjects.isEmpty()) {
+        if(!ret.isEmpty())
+            ret += ":  ";
+        
+        QStringList projectNames;
+        
+        foreach(KUrl url, openProjects)
+        {
+            QString projectName = url.fileName();
+            if(projectName.endsWith(".kdev4"))
+                projectName = projectName.left(projectName.size()-6);
+            projectNames << projectName;
+        }
+        
+        ret += projectNames.join(", ");
+    }
+    
+    return ret;
+}
+
 KUrl Session::pluginDataArea( const IPlugin* p )
 {
     return d->pluginArea( p );
