@@ -60,8 +60,8 @@ namespace KDevelop {
 
 struct TextDocumentPrivate {
     TextDocumentPrivate(TextDocument *textDocument)
-        : m_textDocument(textDocument)
-        , m_loaded(false), encoding("")
+        : encoding(""), m_textDocument(textDocument)
+        , m_loaded(false)
     {
         document = 0;
         state = IDocument::Clean;
@@ -198,8 +198,6 @@ public:
 TextDocument::TextDocument(const KUrl &url, ICore* core, const QString& encoding)
     :PartDocument(url, core), d(new TextDocumentPrivate(this))
 {
-    if (url.url().endsWith("kdevtmp"))
-        setTitle(i18n("Untitled"));
     d->encoding = encoding;
 }
 
@@ -237,7 +235,7 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
         if (!d->encoding.isEmpty())
             d->document->setEncoding(d->encoding);
 
-        if (!url().isEmpty())
+        if (!url().isEmpty() && !DocumentController::isEmptyDocumentUrl(url()))
             d->document->openUrl( url() );
 
         /* It appears, that by default a part will be deleted the the
@@ -363,8 +361,11 @@ bool TextDocument::save(DocumentSaveMode mode)
             break;
     }
 
+    KUrl urlBeforeSave = d->document->url();
     if (d->document->save())
     {
+        if (d->document->url() != urlBeforeSave)
+            notifyUrlChanged();
         return true;
     }
     return false;
@@ -377,17 +378,21 @@ IDocument::DocumentState TextDocument::state() const
 
 KTextEditor::Cursor KDevelop::TextDocument::cursorPosition() const
 {
+    if (!d->document) {
+        return KTextEditor::Cursor::invalid();
+    }
+
     KTextEditor::View *view = d->document->activeView();
 
     if (view)
         return view->cursorPosition();
 
-    return KTextEditor::Cursor();
+    return KTextEditor::Cursor::invalid();
 }
 
 void TextDocument::setCursorPosition(const KTextEditor::Cursor &cursor)
 {
-    if (!cursor.isValid())
+    if (!cursor.isValid() || !d->document)
         return;
 
     KTextEditor::View *view = d->document->activeView();
@@ -401,6 +406,10 @@ void TextDocument::setCursorPosition(const KTextEditor::Cursor &cursor)
 
 KTextEditor::Range TextDocument::textSelection() const
 {
+    if (!d->document) {
+        return KTextEditor::Range::invalid();
+    }
+
     KTextEditor::View *view = d->document->activeView();
 
     if (view && view->selection()) {
@@ -412,6 +421,10 @@ KTextEditor::Range TextDocument::textSelection() const
 
 QString TextDocument::textLine() const
 {
+    if (!d->document) {
+        return QString();
+    }
+
     KTextEditor::View *view = d->document->activeView();
 
     if (view) {
@@ -423,6 +436,10 @@ QString TextDocument::textLine() const
 
 QString TextDocument::textWord() const
 {
+    if (!d->document) {
+        return QString();
+    }
+
     KTextEditor::View *view = d->document->activeView();
 
     if (view) {
@@ -453,7 +470,7 @@ QString TextDocument::textWord() const
 
 void TextDocument::setTextSelection(const KTextEditor::Range &range)
 {
-    if (!range.isValid())
+    if (!range.isValid() || !d->document)
         return;
 
     KTextEditor::View *view = d->document->activeView();
@@ -469,8 +486,10 @@ bool TextDocument::close(DocumentSaveMode mode)
     if (!PartDocument::close(mode))
         return false;
 
-    KDevelop::EditorIntegrator::removeDocument(d->document);
-    delete d->document; //We have to delete the document right now, to prevent random crashes in the event handler
+    if ( d->document ) {
+        KDevelop::EditorIntegrator::removeDocument(d->document);
+        delete d->document; //We have to delete the document right now, to prevent random crashes in the event handler
+    }
 
     return true;
 }
@@ -592,9 +611,12 @@ KDevelop::TextEditorWidget::~TextEditorWidget()
     delete d;
 }
 
-void KDevelop::TextEditorWidget::viewStatusChanged(KTextEditor::View*, const KTextEditor::Cursor& newPosition)
+void KDevelop::TextEditorWidget::viewStatusChanged(KTextEditor::View* view, const KTextEditor::Cursor& )
 {
-    d->status = i18n(" Line: %1 Col: %2 ", KGlobal::locale()->formatNumber(newPosition.line() + 1, 0), KGlobal::locale()->formatNumber(newPosition.column() + 1, 0));
+    // This fetches the virtual cursor, which expands tab characters properly, i.e. instead of col == 1
+    // you'll get col == 9 with this when a tab is at the start of the line.
+    KTextEditor::Cursor pos = view->cursorPositionVirtual();
+    d->status = i18n(" Line: %1 Col: %2 ", KGlobal::locale()->formatNumber(pos.line() + 1, 0), KGlobal::locale()->formatNumber(pos.column() + 1, 0));
     emit statusChanged();
 }
 
