@@ -157,12 +157,6 @@ public:
     }
 
     QString id() const { return m_factory->id(); }
-    
-    bool viewsWantProgressIndicator() const 
-    {
-            return m_factory->viewsWantProgressIndicator();
-    }
-
 private:
     IToolViewFactory *m_factory;
 };
@@ -199,7 +193,7 @@ UiController::UiController(Core *core)
     assistantaction2->setText( i18n("&Assistant Action 2") );
     assistantaction2->setShortcut( Qt::ALT | Qt::Key_2 );
     connect(assistantaction2, SIGNAL(triggered(bool)), this, SLOT(assistantAction2(bool)));
-            
+
     KAction* assistantaction3 = actions->addAction("assistant_action_3");
     assistantaction3->setText( i18n("&Assistant Action 3") );
     assistantaction3->setShortcut( Qt::ALT | Qt::Key_3 );
