@@ -43,6 +43,7 @@
 #include <qpushbutton.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
+#include <interfaces/isession.h>
 
 using namespace KDevelop;
 
@@ -75,9 +76,13 @@ void filterViews(QSet< QString > keepFiles)
 QStringList setIcons = QStringList() << "chronometer" << "games-config-tiles" << "im-user" << "irc-voice" << "irc-operator" << "office-chart-pie" << "office-chart-ring" << "speaker" << "view-pim-notes" << "esd" << "akonadi" << "kleopatra" << "nepomuk" << "package_edutainment_art" << "package_games_amusement" << "package_games_sports" << "package_network" << "package_office_database" << "package_system_applet" << "package_system_emulator" << "preferences-desktop-notification-bell" << "wine" << "utilities-desktop-extra" << "step" << "preferences-web-browser-cookies" << "preferences-plugin" << "preferences-kcalc-constants" << "preferences-desktop-icons" << "tagua" << "inkscape" << "java" << "kblogger" << "preferences-desktop-personal" << "emblem-favorite" << "face-smile-big" << "face-embarrassed" << "user-identity" << "mail-tagged" << "media-playlist-suffle" << "weather-clouds";
 
 WorkingSetController::WorkingSetController(Core* core) : m_core(core)
+{
+}
+
+void WorkingSetController::initialize()
 {
     //Load all working-sets
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     foreach(QString set, setConfig.groupList())                                                                                                                                                
         getWorkingSet(set);  
 }
@@ -167,7 +172,7 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
     kDebug() << "saving" << m_id << "from area";
     
     ///@todo Make the working-sets session-specific
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
     deleteGroupRecursive(group);
     saveFromArea(area, areaIndex, group);
@@ -215,52 +220,37 @@ bool WorkingSet::isEmpty() const
 {
     if(m_id.isEmpty())
         return true;
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
     return !group.hasKey("Orientation") && group.readEntry("View Count", 0) == 0;
 }
 
-struct DisconnectMainWindowsFromArea
+struct DisableMainWindowUpdatesFromArea
 {
-    DisconnectMainWindowsFromArea(Sublime::Area* area) : m_area(area) {
+    DisableMainWindowUpdatesFromArea(Sublime::Area* area) : m_area(area) {
         if(area) {
             
             foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
                 if(window->area() == area) {
-                    mainWindows << window;
-                    oldActiveView = window->activeView();
-                    bool hadTempArea = false;
-                    foreach(Sublime::Area* tempArea, Core::self()->uiControllerInternal()->areas(window)) {
-                        if(tempArea != area) {
-                            ///@todo This is insanely ugly..
-                            window->setUpdatesEnabled(false);
-                            kDebug() << "changing temporarily to area" << tempArea->objectName();
-                            Core::self()->uiControllerInternal()->showArea(tempArea->objectName(), window); //Show another area temporarily
-                            hadTempArea = true;
-                            break;
-                        }
+                    if(window->updatesEnabled()) {
+                        wasUpdatesEnabled.insert(window);
+                        window->setUpdatesEnabled(false);
                     }
-                    Q_ASSERT(hadTempArea);
                 }
             }
         }
     }
     
-    ~DisconnectMainWindowsFromArea() {
+    ~DisableMainWindowUpdatesFromArea() {
         if(m_area) {
-            foreach(Sublime::MainWindow* window, mainWindows) {
-                kDebug() << "changing back";
-                Core::self()->uiControllerInternal()->showArea(m_area, window);
-                if(oldActiveView)
-                    window->activateView(oldActiveView);
+            foreach(Sublime::MainWindow* window, wasUpdatesEnabled) {
                 window->setUpdatesEnabled(true);
             }
         }
     }
 
     Sublime::Area* m_area;
-    QList<Sublime::MainWindow*> mainWindows;
-    QPointer<Sublime::View> oldActiveView;
+    QSet<Sublime::MainWindow*> wasUpdatesEnabled;
 };
 
 void loadFileList(QStringList& ret, KConfigGroup group)
@@ -298,7 +288,7 @@ QStringList WorkingSet::fileList() const
         return QStringList();
     
     QStringList ret;
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
 
     loadFileList(ret, group);
@@ -308,7 +298,7 @@ QStringList WorkingSet::fileList() const
 void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, bool clear) {
     PushValue<bool> enableLoading(m_loading, true);
     
-    DisconnectMainWindowsFromArea disconnectArea(area);
+    DisableMainWindowUpdatesFromArea updatesDisabler(area);
     
     kDebug() << "loading working-set" << m_id << "into area" << area;
     
@@ -325,29 +315,38 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
     if(m_id.isEmpty())
         return;
     
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
 
-    loadToArea(area, areaIndex, group);
+    loadToArea(area, areaIndex, false, group);
+    
+    //activate first view in the working set
+    if (!area->views().isEmpty()) {
+        foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
+            if(window->area() == area) {
+                window->activateView(area->views().first());
+            }
+        }
+    }
 }
 
-void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, KConfigGroup group)
+void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, bool split, KConfigGroup group)
 {
     if (group.hasKey("Orientation")) {
         QStringList subgroups = group.groupList();
 
         if (subgroups.contains("0")) {
-            if (!areaIndex->isSplitted()) {
-                areaIndex->split(group.readEntry("Orientation", "Horizontal") == "Vertical" ? Qt::Vertical : Qt::Horizontal);
-            }
+            split = false;
+            if (!areaIndex->isSplitted())
+                split = true;
 
             KConfigGroup subgroup(&group, "0");
-            loadToArea(area, areaIndex->first(), subgroup);
+            loadToArea(area, areaIndex, split, subgroup);
 
             if (subgroups.contains("1")) {
                 Q_ASSERT(areaIndex->isSplitted());
                 KConfigGroup subgroup(&group, "1");
-                loadToArea(area, areaIndex->second(), subgroup);
+                loadToArea(area, areaIndex->second(), false, subgroup);
             }
         }
 
@@ -383,7 +382,12 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
                 if (!state.isEmpty())
                     view->setState(state);
 
-                area->addView(view, areaIndex);
+                if (i == 0 && split) {
+                    Qt::Orientation orientation = group.parent().readEntry("Orientation", "Horizontal") == "Vertical" ? Qt::Vertical : Qt::Horizontal;
+                    area->addView(view, areaIndex, orientation);
+                    areaIndex = areaIndex->first();
+                } else
+                    area->addView(view, areaIndex);
             } else {
                 kWarning() << "Unable to create view of type " << type;
             }
@@ -394,7 +398,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
 void WorkingSet::deleteSet(bool force, bool silent)
 {
     if((m_areas.isEmpty() || force) && !m_id.isEmpty()) {
-        KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+        KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
         KConfigGroup group = setConfig.group(m_id);
         deleteGroupRecursive(group);
         
@@ -836,7 +840,7 @@ WorkingSetToolButton::WorkingSetToolButton(QWidget* parent, WorkingSet* set, Mai
 void WorkingSet::setPersistent(bool persistent) {
     if(m_id.isEmpty())
         return;
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
     group.writeEntry("persistent", persistent);
 }
@@ -844,7 +848,7 @@ void WorkingSet::setPersistent(bool persistent) {
 bool WorkingSet::isPersistent() const {
     if(m_id.isEmpty())
         return false;
-    KConfigGroup setConfig(KGlobal::config(), "Working File Sets");
+    KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup group = setConfig.group(m_id);
     return group.readEntry("persistent", false);
 }
