@@ -179,6 +179,7 @@ void Container::setLeftCornerWidget(QWidget* widget)
         return;
     widget->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
     m_tabBarLayout->insertWidget(0, widget);
+    widget->show();
 }
 
 Container::~Container()
@@ -221,7 +222,6 @@ void Container::widgetActivated(int idx)
     if (idx < 0)
         return;
     if (QWidget* w = d->stack->widget(idx)) {
-        w->setFocus();
         if(d->viewForWidget.contains(w))
             emit activateView(d->viewForWidget[w]);
     }
@@ -237,7 +237,7 @@ void Container::addWidget(View *view)
         view->notifyPositionChanged(idx);
     }
     else
-        d->stack->addWidget(w);
+        idx = d->stack->addWidget(w);
     d->tabBar->insertTab(idx, view->document()->statusIcon(), view->document()->title());
     d->viewForWidget[w] = view;
     connect(view, SIGNAL(statusChanged(Sublime::View*)), this, SLOT(statusChanged(Sublime::View*)));
@@ -315,8 +315,9 @@ int Container::indexOf(QWidget* w) const
 void Sublime::Container::removeWidget(QWidget *w)
 {
     if (w) {
-        d->tabBar->removeTab(d->stack->indexOf(w));
+        int widgetIdx = d->stack->indexOf(w);
         d->stack->removeWidget(w);
+        d->tabBar->removeTab(widgetIdx);
         if (d->tabBar->currentIndex() != -1)
             d->fileNameCorner->setText(d->tabBar->tabText(d->tabBar->currentIndex()));
         View* view = d->viewForWidget.take(w);
@@ -377,6 +378,7 @@ void Container::contextMenu( int currentTab, QPoint pos )
     menu.addSeparator();
     QAction* closeTabAction = menu.addAction( KIcon("document-close"), i18n( "Close File" ) );
     QAction* closeOtherTabsAction = menu.addAction( KIcon("document-close"), i18n( "Close Other Files" ) );
+    QAction* closeAllTabsAction = menu.addAction( KIcon("document-close"), i18n( "Close All Files" ) );
 
     QAction* triggered = menu.exec(pos);
 
@@ -397,6 +399,13 @@ void Container::contextMenu( int currentTab, QPoint pos )
             foreach( QWidget* tab, otherTabs ) {
                 closeRequest(tab);
             }
+        } else if ( triggered == closeAllTabsAction ) {
+            // activate last tab
+            widgetActivated(count() - 1);
+            // close all
+            while ( count() ) {
+                closeRequest(widget(0));
+            }
         } // else the action was handled by someone else
     }
 }
