@@ -25,6 +25,8 @@
 
 #include "sublimeexport.h"
 
+class QIcon;
+
 class QWidget;
 
 namespace Sublime {
@@ -65,6 +67,21 @@ public:
     /**@return the specifics of this document which can be written to config.*/
     virtual QString documentSpecifier() const = 0;
 
+    /**Should try closing the document, eventually asking the user for feedback.
+      *
+      *If closing is successful, all views should be deleted, and the document itself
+      *be scheduled for deletion using deleteLater().
+      *
+      *The default implementation will close all views and then deletes the document itself.
+      *Override this if you want to confirm closing with the user.
+      *
+      * Returns whether closing was successful (The user did not push 'Cancel') */
+    virtual bool closeDocument();
+
+    void setStatusIcon(QIcon icon);
+    
+    QIcon statusIcon() const;
+    
 Q_SIGNALS:
     /**Emitted when the view is added or deleted. Use Document::views to find out
     which views and how many of them are still there.*/
@@ -73,6 +90,8 @@ Q_SIGNALS:
     void aboutToDelete(Sublime::Document *doc);
     /**Emitted when the document's title is changed.*/
     void titleChanged(Sublime::Document *doc);
+   /**Emitted when the document status-icon has changed */
+    void statusIconChanged(Sublime::Document *doc);
 
 protected:
     /**Creates and returns the new view. Reimplement in subclasses to instantiate
