@@ -42,14 +42,13 @@
 using namespace Sublime;
 
 IdealToolButton::IdealToolButton(Qt::DockWidgetArea area, QWidget *parent)
-    : KAnimatedButton(parent), _area(area), showingIndicator( false )
+    : QToolButton(parent), _area(area)
 {
     setFocusPolicy(Qt::NoFocus);
     KAcceleratorManager::setNoAccel(this);
     setCheckable(true);
     setAutoRaise(true);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-    setIcons( "process-working-kde" );
 
     setContextMenuPolicy(Qt::CustomContextMenu);
 }
@@ -62,29 +61,6 @@ Qt::Orientation IdealToolButton::orientation() const
     return Qt::Horizontal;
 }
 
-void IdealToolButton::hideProgressIndicator()
-{
-    stop();
-    setIcon( normalIcon );
-    showingIndicator = false;
-}
-
-void IdealToolButton::showProgressIndicator()
-{
-    setIcons( "process-working-kde" );
-    showingIndicator = true;
-    start();
-}
-
-void IdealToolButton::updateNormalIcon( const QIcon& icon )
-{
-    normalIcon = icon;
-    if( !showingIndicator )
-    {
-        setIcon( icon );
-    }
-}
-
 QSize IdealToolButton::sizeHint() const
 {
     ensurePolished();
@@ -223,8 +199,6 @@ QWidget* IdealButtonBarWidget::corner()
 
 void IdealButtonBarWidget::removeAction(QAction * action)
 {
-    disconnect(_widgets[action]->view(), SIGNAL(showProgressIndicator()), _buttons[action], 0);
-    disconnect(_widgets[action]->view(), SIGNAL(hideProgressIndicator()), _buttons[action], 0);
     _widgets.remove(action);
     delete _buttons.take(action);
     delete action;
@@ -292,14 +266,16 @@ void IdealButtonBarWidget::actionEvent(QActionEvent *event)
             _buttons.insert(action, button);
 
             button->setText(action->text());
-            button->updateNormalIcon(action->icon());
+            button->setIcon(action->icon());
             button->setShortcut(QKeySequence());
             button->setChecked(action->isChecked());
+
+            Q_ASSERT(_widgets.contains(action));
+            _widgets[action]->setWindowTitle(action->text());
+
             layout()->addWidget(button);
             connect(action, SIGNAL(toggled(bool)), SLOT(actionToggled(bool)));
             connect(button, SIGNAL(toggled(bool)), action, SLOT(setChecked(bool)));
-            connect(_widgets[action]->view(), SIGNAL(showProgressIndicator()), button, SLOT(showProgressIndicator()));
-            connect(_widgets[action]->view(), SIGNAL(hideProgressIndicator()), button, SLOT(hideProgressIndicator()));
             connect(button, SIGNAL(customContextMenuRequested(QPoint)),
                     _widgets[action], SLOT(contextMenuRequested(QPoint)));
         }
@@ -323,7 +299,7 @@ void IdealButtonBarWidget::actionEvent(QActionEvent *event)
     case QEvent::ActionChanged: {
         if (IdealToolButton *button = _buttons.value(action)) {
             button->setText(action->text());
-            button->updateNormalIcon(action->icon());
+            button->setIcon(action->icon());
             button->setShortcut(QKeySequence());
             Q_ASSERT(_widgets.contains(action));
             _widgets[action]->setWindowTitle(action->text());
@@ -468,6 +444,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     Q_ASSERT(senderWidget);
 
     KMenu menu;
+    menu.addTitle(windowIcon(), windowTitle());
 
     /// start position menu
     QMenu* positionMenu = menu.addMenu(i18n("Position"));
@@ -504,6 +481,20 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
         toggleAnchored = menu.addAction(KIcon("document-encrypt"), i18n("Lock"));
     }
 
+    if ( QMainWindow* toolView = qobject_cast<QMainWindow*>(widget()) ) {
+        menu.addSeparator();
+        QToolBar* bar = 0;
+        foreach( QObject* child, toolView->children() ) {
+            if ( bar = qobject_cast<QToolBar*>(child) ) {
+                break;
+            }
+        }
+        Q_ASSERT(bar);
+        menu.addActions(bar->actions());
+        menu.addSeparator();
+        menu.addAction(bar->toggleViewAction());
+    }
+
     QAction* triggered = menu.exec(senderWidget->mapToGlobal(point));
 
     if (triggered)
@@ -523,8 +514,10 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
             pos = Sublime::Bottom;
         else if (triggered == right)
             pos = Sublime::Right;
-        else
+        else if (triggered == top)
             pos = Sublime::Top;
+        else
+            return;
 
         Area *area = m_area;
         View *view = m_view;
@@ -877,6 +870,7 @@ IdealSplitterHandle::IdealSplitterHandle(Qt::Orientation orientation, QWidget* p
     : QWidget(parent)
     , m_orientation(orientation)
     , m_hover(false)
+    , m_pressed(false)
     , m_resizeRole(resizeRole)
 {
     setCursor(orientation == Qt::Horizontal ? Qt::SplitVCursor : Qt::SplitHCursor);
@@ -894,6 +888,10 @@ void IdealSplitterHandle::paintEvent(QPaintEvent *)
     options.state |= QStyle::State_Horizontal;
 
     options.state |= QStyle::State_Enabled;
+    if (m_hover)
+        options.state |= QStyle::State_MouseOver;
+    if (m_pressed)
+        options.state |= QStyle::State_Sunken;
 
     painter.drawControl(QStyle::CE_Splitter, options);
 }
@@ -921,8 +919,31 @@ void IdealSplitterHandle::mouseMoveEvent(QMouseEvent * event)
 
 void IdealSplitterHandle::mousePressEvent(QMouseEvent * event)
 {
-    if (event->button() == Qt::LeftButton)
+    if (event->button() == Qt::LeftButton) {
         m_dragStart = convert(event->pos());
+        m_pressed = true;
+        update();
+    }
+}
+
+void IdealSplitterHandle::mouseReleaseEvent(QMouseEvent* event)
+{
+    if (event->button() == Qt::LeftButton) {
+        m_pressed = false;
+        update();
+    }
+}
+
+void IdealSplitterHandle::enterEvent(QEvent* /*event*/)
+{
+    m_hover = true;
+    update();
+}
+
+void IdealSplitterHandle::leaveEvent(QEvent* /*event*/)
+{
+    m_hover = false;
+    update();
 }
 
 IdealMainWidget * IdealButtonBarWidget::parentWidget() const
