@@ -103,6 +103,11 @@ protected:
     virtual void initializeStatusBar();
 protected Q_SLOTS:
     virtual void setupAreaSelector();
+    virtual void tabContextMenuRequested(Sublime::View*, KMenu*);
+    /**Called whenever the user requests a context menu on a dockwidget bar.
+       You can then e.g. add actions to add dockwidgets.
+       Default implementation does nothing.**/
+    virtual void dockBarContextMenuRequested(Qt::DockWidgetArea, const QPoint&);
 
 public: // FIXME?
     /**Saves size/toolbar/menu/statusbar settings to the global configuration file.
@@ -142,7 +147,7 @@ private:
     void saveGeometry(KConfigGroup &config);
     void loadGeometry(const KConfigGroup &config);
 
-    struct MainWindowPrivate *const d;
+    class MainWindowPrivate *const d;
     friend class MainWindowOperator;
     friend class MainWindowPrivate;
 };
