@@ -87,8 +87,7 @@ DistributedVersionControlPlugin::DistributedVersionControlPlugin(QObject *parent
 
 DistributedVersionControlPlugin::~DistributedVersionControlPlugin()
 {
-    if (!core()->uiController())
-        delete d->m_factory; // When there is a GUI, it will probably owned by UIController
+    //TODO: Find out why this crashes on the svn tests delete d->m_factory;
     delete d;
 }
 
@@ -349,8 +348,9 @@ void DistributedVersionControlPlugin::checkoutFinished(KJob* _checkoutJob)
 
     core()->projectController()->closeProject(curProject); //let's ask to save all files!
 
-    if (!checkoutJob->exec())
+    if (!checkoutJob->exec()) {
         kDebug() << "CHECKOUT PROBLEM!";
+    }
 
     kDebug() << "projectFile is " << projectFile << " JobDir is " << workingDir;
     kDebug() << "Project was closed, now it will be opened";
@@ -400,7 +400,7 @@ QString DistributedVersionControlPlugin::stripPathToDir(const QString &path)
 {
     QFileInfo repoInfo = QFileInfo(path);
     if (repoInfo.isFile())
-        return repoInfo.path();
+        return repoInfo.path() + QDir::separator();
     else if (path.endsWith(QDir::separator()))
         return path;
     else
