@@ -33,7 +33,6 @@ namespace KDevelop
 {
 
 class VcsJob;
-class VcsMapping;
 class VcsLocation;
 class VcsImportMetadataWidget;
 /**
@@ -107,7 +106,7 @@ public:
      * @returns a job that executes the addition
      */
     virtual VcsJob* add( const KUrl::List& localLocations,
-                         RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                         RecursionMode recursion = IBasicVersionControl::Recursive ) = 0;
 
     /**
      * removes a local versioned file or directory from the version control system
@@ -131,7 +130,7 @@ public:
                           const KUrl& localLocationDst ) = 0;
 
     virtual VcsJob* status( const KUrl::List& localLocations,
-                            RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                            RecursionMode recursion = IBasicVersionControl::Recursive ) = 0;
 
     /**
      * revert all local changes on the given file, making its content equal
@@ -139,7 +138,7 @@ public:
      * unedit() (if not a no-op) is implied.
      */
     virtual VcsJob* revert( const KUrl::List& localLocations,
-                            RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                            RecursionMode recursion = IBasicVersionControl::Recursive ) = 0;
 
     /**
      * fetches the latest changes from the repository, if there are
@@ -153,27 +152,26 @@ public:
      */
     virtual VcsJob* update( const KUrl::List& localLocations,
                             const VcsRevision& rev = VcsRevision::createSpecialRevision( VcsRevision::Head ),
-                            RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                            RecursionMode recursion = IBasicVersionControl::Recursive ) = 0;
 
     /**
      * Checks in the changes of the given file(s)/dir(s) into the repository
      */
     virtual VcsJob* commit( const QString& message,
                             const KUrl::List& localLocations,
-                            RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                            RecursionMode recursion = IBasicVersionControl::Recursive ) = 0;
 
     /**
-     * Retrieves a diff between the two locations at the given revisions
+     * Retrieves a diff between two revisions of a file
      *
      * The diff is in unified diff format for text files by default
      */
-    virtual VcsJob* diff( const VcsLocation& localOrRepoLocationSrc,
-                          const VcsLocation& localOrRepoLocationDst,
+    virtual VcsJob* diff( const KUrl& fileOrDirectory,
                           const VcsRevision& srcRevision,
                           const VcsRevision& dstRevision,
-                          VcsDiff::Type = KDevelop::VcsDiff::DiffUnified,
+                          VcsDiff::Type = VcsDiff::DiffUnified,
                           IBasicVersionControl::RecursionMode recursion
-                                       = KDevelop::IBasicVersionControl::Recursive ) = 0;
+                                       = IBasicVersionControl::Recursive ) = 0;
 
     /**
      * Retrieve the history of a given local url
@@ -222,17 +220,6 @@ public:
     virtual VcsJob* annotate( const KUrl& localLocation,
                               const VcsRevision& rev = VcsRevision::createSpecialRevision( VcsRevision::Head ) ) = 0;
 
-    /**
-     * merge/integrate the changes between src and dest into the given local file
-     *
-     * Note: This might create conflicts in the file(s) that are changed
-     */
-    virtual VcsJob* merge( const VcsLocation& localOrRepoLocationSrc,
-                           const VcsLocation& localOrRepoLocationDst,
-                           const VcsRevision& srcRevision,
-                           const VcsRevision& dstRevision,
-                           const KUrl& localLocation ) = 0;
-
     /**
      * check for conflicts in the given file and eventually present a
      * conflict solving dialog to the user
@@ -241,11 +228,15 @@ public:
                              RecursionMode recursion ) = 0;
 
     /**
-     * Checks out files or dirs from a repository (in DVCS from any commit) into a local directory
-     * hierarchy. The mapping exactly tells which file in the repository
-     * should go to which local file
+     * Creates a working copy of the latest revision of the repository sourceRepository in
+     * the newly created directory destinationDirectory.
+     * In the case of a decentralized VCSs, there is no working copy without repository,
+     * therefor checkout() includes the creation of a local copy of the repository.
+     * 
+     * @param sourceRepository source of the checkout
+     * @param destinationDirectory location of the created working copy (local repository)
      */
-    virtual VcsJob* checkout( const VcsMapping& mapping ) = 0;
+    virtual VcsJob* createWorkingCopy(const VcsLocation & sourceRepository, const KUrl & destinationDirectory, RecursionMode recursion = IBasicVersionControl::Recursive) = 0;
 
 };
 
